@@ -72,7 +72,7 @@ class vis_tools:
             magnitude += 1 
             num /= 1000.0 
         # add more suffixes if you need them 
-        return '%.0f%s' % (num, ['', 'K', 'M', 'G', 'T', 'P'][magnitude])
+        return '%.2f%s' % (num, ['', 'K', 'M', 'B', 'T', 'P'][magnitude])
 
     def single_bar_chart(
         self
@@ -150,7 +150,10 @@ class vis_tools:
         ax.yaxis.set_tick_params(labelsize=self.label_size)
             
         for i,v in enumerate(y_list):
-            ax.text(v+y_max/20,i-0.2, self.human_format(v))
+            if v>=0:
+                ax.text(v+y_max/20,i-0.2, self.human_format(v))
+            if v<0:
+                ax.text(v-y_max/20,i-0.2, self.human_format(v))
             ax.set_xticks([])    
         
         ax.spines[['top','right','bottom']].set_visible(False)
@@ -187,7 +190,7 @@ class vis_tools:
         ax.set_xticklabels(x_list)
         ax.set_ylim(bottom=0)
 
-        ax.text(max(x_label_index),y_list[-1],line1_name,**self.label_text_font,color=self.dark_blue)
+        ax.text(max(x_label_index)+1,y_list[-1],line1_name,**self.label_text_font,color=self.dark_blue)
         #ax.get_yaxis().set_major_formatter(matplotlib.ticker.FuncFormatter(lambda x, p: format(int(x), ',')))
         ax.get_yaxis().set_major_formatter(matplotlib.ticker.FuncFormatter(lambda x, p:self.human_format(x)))
 
